package org.eclipse.jdt.internal.compiler.lookup;

package .var.folders._j.vfbv187d0bb8b8w5spzgg8180000gn.T;

import org.eclipse.jdt.internal.compiler.lookup.AnnotationBinding;
import org.eclipse.jdt.internal.compiler.lookup.BinaryTypeBinding;
import org.eclipse.jdt.internal.compiler.lookup.ElementValuePair;
import org.eclipse.jdt.internal.compiler.lookup.LookupEnvironment;
import org.eclipse.jdt.internal.compiler.lookup.MethodBinding;
import org.eclipse.jdt.internal.compiler.lookup.ReferenceBinding;
import org.eclipse.jdt.internal.compiler.lookup.TypeBinding;
import org.eclipse.jdt.internal.compiler.lookup.UnresolvedReferenceBinding;

public class UnresolvedAnnotationBinding extends AnnotationBinding {
  private LookupEnvironment env;
  
  private boolean typeUnresolved = true;
  
  UnresolvedAnnotationBinding(ReferenceBinding type, ElementValuePair[] pairs, LookupEnvironment env) {
    super(type, pairs);
    this.env = env;
  }
  
  public void resolve() {
    if (this.typeUnresolved) {
      boolean wasToleratingMissingTypeProcessingAnnotations = this.env.mayTolerateMissingType;
      this.env.mayTolerateMissingType = true;
      try {
        this.type = (ReferenceBinding)BinaryTypeBinding.resolveType((TypeBinding)this.type, this.env, false);
      } finally {
        this.env.mayTolerateMissingType = wasToleratingMissingTypeProcessingAnnotations;
      } 
      this.typeUnresolved = false;
    } 
  }
  
  public ReferenceBinding getAnnotationType() {
    resolve();
    return this.type;
  }
  
  public ElementValuePair[] getElementValuePairs() {
    if (this.env != null) {
      if (this.typeUnresolved)
        resolve(); 
      for (int i = this.pairs.length; --i >= 0; ) {
        ElementValuePair pair = this.pairs[i];
        MethodBinding[] methods = this.type.getMethods(pair.getName());
        if (methods != null && methods.length == 1)
          pair.setMethodBinding(methods[0]); 
        Object value = pair.getValue();
        if (value instanceof UnresolvedReferenceBinding)
          pair.setValue(((UnresolvedReferenceBinding)value)
              .resolve(this.env, false)); 
      } 
      this.env = null;
    } 
    return this.pairs;
  }
}
